@@ -28,7 +28,11 @@ var CORE = p5pkg.CORE;
 
 var isNode = typeof require != "undefined";
 
+EOT
 
+# sleep()
+
+    . <<'EOT'
 if (isNode) {
     try {
         var sleep = require("sleep");
@@ -50,6 +54,40 @@ if (!CORE.sleep) {
     }
 }
 
+EOT
+
+# crypt()
+
+    . <<'EOT'
+if (isNode) {
+    try {
+        var crypt = require("crypt3");
+        CORE.crypt = function(List__) {
+            var text = p5str(List__[0]);
+            var salt = p5str(List__[1]);
+            while(salt.length() < 2) {
+                salt += "A";
+            }
+            return crypt(text, salt);
+        }
+    }
+    catch (err) {
+        CORE.crypt = function(List__) {
+            CORE.die("crypt() function failed. Maybe you need 'npm install crypt3'?\n" + err);
+        }
+    }
+}
+if (!CORE.crypt) {
+    CORE.crypt = function(List__) {
+        CORE.die("crypt() not supported for this platform");
+    }
+}
+
+EOT
+
+# time()
+
+    . <<'EOT'
 CORE.time = function(List__) {
     return CORE.int([Date.now() / 1000]);
 }
@@ -178,6 +216,7 @@ CORE.oct = function(List__) {
 
     var re = new RegExp('_', 'g');
     v = v.replace(re, "");
+    var result;
 
     if (b == "0b" || b == "0B") {
         for(var i = 2; i < v.length; i++) {
@@ -188,10 +227,9 @@ CORE.oct = function(List__) {
             }
         }
         if (v.length == 2) { return 0 }
-        return parseInt(v.substr(2), 2);
+        result = parseInt(v.substr(2), 2);
     }
-
-    if (b == "0x" || b == "0X") {
+    else if (b == "0x" || b == "0X") {
         for(var i = 2; i < v.length; i++) {
             var c = v.substr(i,1);
             if (c >= "0" && c <= "9" || c >= "A" && c <= "F" || c >= "a" && c <= "f") {}
@@ -200,10 +238,12 @@ CORE.oct = function(List__) {
             }
         }
         if (v.length == 2) { return 0 }
-        return parseInt(v.substr(2), 16);
+        result = parseInt(v.substr(2), 16);
     }
-
-    return parseInt(v, 8);
+    else {
+        result = parseInt(v, 8);
+    }
+    return isNaN(result) ? 0 : result;
 };
 
 CORE.abs   = function(List__) { return Math.abs(List__[0]) };
